'use strict';

const vscode = require('vscode');

function _interopNamespaceDefault(e) {
    const n = Object.create(null);
    if (e) {
        for (const k in e) {
            if (k !== 'default') {
                const d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        }
    }
    n.default = e;
    return Object.freeze(n);
}

const vscode__namespace = /*#__PURE__*/_interopNamespaceDefault(vscode);

// The module 'vscode' contains the VS Code extensibility API
// Import the module and reference it with the alias vscode in your code below

const typeScriptExtensionId = 'vscode.typescript-language-features';
const pluginId = 'typescript-lit-html-plugin';
const configurationSection = 'lit-html';

async function activate(context) {
    const extension = vscode__namespace.extensions.getExtension(typeScriptExtensionId);

    if (!extension) {
        return;
    }

    await extension.activate();

    if (!extension.exports || !extension.exports.getAPI) {
        return;
    }

    const api = extension.exports.getAPI(0);

    if (!api) {
        return;
    }

    vscode__namespace.workspace.onDidChangeConfiguration(
        (e) => {
            if (e.affectsConfiguration(configurationSection)) {
                synchronizeConfiguration(api);
            }
        },
        undefined,
        context.subscriptions
    );

    synchronizeConfiguration(api);
}

function synchronizeConfiguration(api) {
    api.configurePlugin(pluginId, getConfiguration());
}

function getConfiguration() {
    const config = vscode__namespace.workspace.getConfiguration(configurationSection);
    const outConfig = {
        format: {}
    };

    withConfigValue(config, 'tags', (tags) => {
        outConfig.tags = tags;
    });
    withConfigValue(config, 'format.enabled', (enabled) => {
        outConfig.format.enabled = enabled;
    });

    return outConfig;
}

function withConfigValue(config, key, withValue) {
    const configSetting = config.inspect(key);

    if (!configSetting) {
        return;
    }

    // Make sure the user has actually set the value.
    // VS Code will return the default values instead of `undefined`, even if user has not don't set anything.
    if (
        //
        typeof configSetting.globalValue === 'undefined' &&
        typeof configSetting.workspaceFolderValue === 'undefined' &&
        typeof configSetting.workspaceValue === 'undefined'
    ) {
        return;
    }

    const value = config.get(key, undefined);

    if (typeof value !== 'undefined') {
        withValue(value);
    }
}

function deactivate() {}

exports.activate = activate;
exports.deactivate = deactivate;
